#!/bin/sh
#
# test_version.sh
#
# Checks the version of the running Linux kernel against the 
# kernel header files.  LINUX_SRC contains the path to the
# kernel sources, set by the Makefile.
#
# Used when 'make' is executed.  Does not stop the build, 
# prints a warning if there is a mismatch.

# If LINUX_SRC is not set, use a good default
if test "$LINUX_SRC"x = x 
then
	LINUX_SRC=/usr/src/linux
fi
if test "$NAME"x = x
then
	NAME=device
fi

# Determine the kernel version for both the includes file and in the
# currently running kernel
# IVER = the version of the kernel headers
# KVER = the version of the running kernel
IVER=`echo -e "#include <linux/version.h>\n _UTS_RELEASE UTS_RELEASE" | \
    /lib/cpp -I ${LINUX_SRC}/include | \
    grep UTS_RELEASE | \
    awk '{print $2}' | tr -d \"`
KVER=`uname -r`

if [ -f .kver ]; then 
    OVER=`cat .kver`; 
    if [ $OVER != $IVER ]; then 
	echo "Removing previously built driver for Linux $OVER"; 
	make clean > /dev/null
	echo " "
    fi 
else 
	make clean > /dev/null
fi

# Check whether any of the built modules has unresolved symbols; if so force
# a make clean regardless of kernel version numbers
if which depmod >& /dev/null ; then
    for i in $CHK_OBJS
    do
    	if test -f $i && depmod $i | grep -q "unresolved symbol"; then
		echo "Previously built $i has unresolved symbols; forcing rebuild"
		make clean >& /dev/null
	        echo " "
        fi
    done
fi

# Check version numbers, print warning if mismatch.
echo $IVER > .kver
echo Building $NAME driver for Linux $IVER
echo " " ; 
if [ $IVER != $KVER ]; then 
    echo "WARNING: The current kernel is actually version $KVER." 
    echo " " 
fi
